@@ -1,8 +1,8 @@
 // For background on the hashtable design first implemented in AutoMap, see the following:
 // https://github.com/brandtbucher/automap/blob/b787199d38d6bfa1b55484e5ea1e89b31cc1fa72/automap.c#L12
-
-
 # include <math.h>
+# include "stdbool.h"
+
 # define PY_SSIZE_T_CLEAN
 # include "Python.h"
 
@@ -29,28 +29,24 @@ static PyTypeObject FAMVType;
 static PyTypeObject FAMType;
 static PyObject *NonUniqueError;
 
-
 // The main storage "table" is an array of TableElement
 typedef struct TableElement{
     Py_ssize_t keys_pos;
     Py_hash_t hash;
 } TableElement;
 
-
 // Table configuration; experimentation shows that these values work well:
 # define LOAD 0.9
 # define SCAN 16
 
 const static size_t UCS4_SIZE = sizeof(Py_UCS4);
 
-
 // Partial, two-argument version of PyUnicode_FromKindAndData for consistent templating with bytes version.
 static inline PyObject*
 PyUnicode_FromUCS4AndData(const void *buffer, Py_ssize_t size) {
     return PyUnicode_FromKindAndData(PyUnicode_4BYTE_KIND, buffer, size);
 }
 
-
 typedef enum KeysArrayType{
     KAT_LIST = 0, // must be falsy
 
@@ -85,10 +81,8 @@ typedef enum KeysArrayType{
     KAT_DTps,
     KAT_DTfs,
     KAT_DTas,
-
 } KeysArrayType;
 
-
 NPY_DATETIMEUNIT
 dt_unit_from_array(PyArrayObject* a) {
     // This is based on get_datetime_metadata_from_dtype in the NumPy source, but that function is private. This does not check that the dytpe is of the appropriate type.
@@ -96,7 +90,6 @@ dt_unit_from_array(PyArrayObject* a) {
     return dma->base;
 }
 
-
 NPY_DATETIMEUNIT
 dt_unit_from_scalar(PyDatetimeScalarObject* dts) {
     // Based on convert_pyobject_to_datetime and related usage in datetime.c
@@ -104,8 +97,6 @@ dt_unit_from_scalar(PyDatetimeScalarObject* dts) {
     return dma->base;
 }
 
-
-
 KeysArrayType
 at_to_kat(int array_t, PyArrayObject* a) {
     switch (array_t) {
@@ -178,8 +169,7 @@ at_to_kat(int array_t, PyArrayObject* a) {
     }
 }
 
-
-// To determine when we can use direct array lookups, this function return 1 if we match, 0 if we do not match. Given a keys array type and the kind of lookup key, return true only for the largest KAT types.s
+// To determine when we can use direct array lookups, this function return 1 if we match, 0 if we do not match. Given a keys array type and the kind of lookup key, return true only for the largest KAT types.
 int
 kat_is_kind(KeysArrayType kat, char kind) {
     switch (kat) {
@@ -226,56 +216,56 @@ kat_is_kind(KeysArrayType kat, char kind) {
 }
 
 // Given a KAT, determine if it matches a NumPy dt64 unit.
-int
+bool
 kat_is_datetime_unit(KeysArrayType kat, NPY_DATETIMEUNIT unit) {
     switch (kat) {
         case KAT_DTY:
-            if (unit == NPY_FR_Y ) {return 1;}
+            if (unit == NPY_FR_Y ) {return true;}
             break;
         case KAT_DTM:
-            if (unit == NPY_FR_M ) {return 1;}
+            if (unit == NPY_FR_M ) {return true;}
             break;
         case KAT_DTW:
-            if (unit == NPY_FR_W ) {return 1;}
+            if (unit == NPY_FR_W ) {return true;}
             break;
         case KAT_DTD:
-            if (unit == NPY_FR_D ) {return 1;}
+            if (unit == NPY_FR_D ) {return true;}
             break;
         case KAT_DTh:
-            if (unit == NPY_FR_h ) {return 1;}
+            if (unit == NPY_FR_h ) {return true;}
             break;
         case KAT_DTm:
-            if (unit == NPY_FR_m ) {return 1;}
+            if (unit == NPY_FR_m ) {return true;}
             break;
         case KAT_DTs:
-            if (unit == NPY_FR_s ) {return 1;}
+            if (unit == NPY_FR_s ) {return true;}
             break;
         case KAT_DTms:
-            if (unit == NPY_FR_ms) {return 1;}
+            if (unit == NPY_FR_ms) {return true;}
             break;
         case KAT_DTus:
-            if (unit == NPY_FR_us) {return 1;}
+            if (unit == NPY_FR_us) {return true;}
             break;
         case KAT_DTns:
-            if (unit == NPY_FR_ns) {return 1;}
+            if (unit == NPY_FR_ns) {return true;}
             break;
         case KAT_DTps:
-            if (unit == NPY_FR_ps) {return 1;}
+            if (unit == NPY_FR_ps) {return true;}
             break;
         case KAT_DTfs:
-            if (unit == NPY_FR_fs) {return 1;}
+            if (unit == NPY_FR_fs) {return true;}
             break;
         case KAT_DTas:
-            if (unit == NPY_FR_as) {return 1;}
+            if (unit == NPY_FR_as) {return true;}
             break;
         default: // non dt64 KATs
-            return 0;
+            return false;
     }
-    return 0;
+    return false;
 }
 
 typedef struct FAMObject{
-    PyObject_VAR_HEAD
+    PyObject_HEAD
     Py_ssize_t table_size;
     TableElement *table;    // an array of TableElement structs
     PyObject *keys;
@@ -284,14 +274,12 @@ typedef struct FAMObject{
     Py_UCS4* key_buffer;
 } FAMObject;
 
-
 typedef enum ViewKind{
     ITEMS,
     KEYS,
     VALUES,
 } ViewKind;
 
-
 // Return the end pointer, or the pointer to the location after the last valid character. The end pointer minus the start pointer is the number of characters. For an empty string, all characters are NULL, and the start pointer and end pointer should be equal. NOTE: would like to use strchr(str, '\0') instead of this routine, but some buffers might not have a null terminator and stread by full to the the dt_size.
 static inline Py_UCS4*
 ucs4_get_end_p(Py_UCS4* p_start, Py_ssize_t dt_size) {
@@ -303,7 +291,6 @@ ucs4_get_end_p(Py_UCS4* p_start, Py_ssize_t dt_size) {
     return p_start;
 }
 
-
 static inline char*
 char_get_end_p(char* p_start, Py_ssize_t dt_size) {
     for (char* p = p_start + dt_size - 1; p >= p_start; p--) {
@@ -314,7 +301,6 @@ char_get_end_p(char* p_start, Py_ssize_t dt_size) {
     return p_start;
 }
 
-
 // This masks the input with INT64_MAX, which removes the MSB; we then cast to an int64; the range is now between 0 and INT64_MAX. We then use the MSB of the original value; if set, we negate the number, producing negative values for the upper half of the uint64 range. Note that we only need to check for hash -1 in this branch.
 static inline Py_hash_t
 uint_to_hash(npy_uint64 v) {
@@ -337,7 +323,6 @@ int_to_hash(npy_int64 v) {
     return hash;
 }
 
-
 // This is a adapted from https://github.com/python/cpython/blob/ba65a065cf07a7a9f53be61057a090f7311a5ad7/Python/pyhash.c#L92
 #define HASH_MODULUS (((size_t)1 << 61) - 1)
 #define HASH_BITS 61
@@ -379,7 +364,6 @@ double_to_hash(double v)
     return (Py_hash_t)x;
 }
 
-
 // The `str` arg is a pointer to a C-array of Py_UCS4; we will only read `len` characters from this. This is a "djb2" hash algorithm.
 static inline Py_hash_t
 unicode_to_hash(Py_UCS4 *str, Py_ssize_t len) {
@@ -395,7 +379,6 @@ unicode_to_hash(Py_UCS4 *str, Py_ssize_t len) {
     return hash;
 }
 
-
 static inline Py_hash_t
 string_to_hash(char *str, Py_ssize_t len) {
     char* p = str;
@@ -410,17 +393,14 @@ string_to_hash(char *str, Py_ssize_t len) {
     return hash;
 }
 
-
 //------------------------------------------------------------------------------
 // the global int_cache is shared among all instances
 
 static PyObject *int_cache = NULL;
 
-
 // NOTE: this used to be a Py_ssize_t, which can be 32 bits on some machines and might easily overflow with a few very large indices. Using an explicit 64-bit int seems safer
 static npy_int64 key_count_global = 0;
 
-
 // Fill the int_cache up to size_needed with PyObject ints; `size` is not the key_count_global.
 static int
 int_cache_fill(Py_ssize_t size_needed)
@@ -446,7 +426,6 @@ int_cache_fill(Py_ssize_t size_needed)
     return 0;
 }
 
-
 // Given the current key_count_global, remove cache elements only if the key_count is less than the the current size of the int_cache.
 void
 int_cache_remove(Py_ssize_t key_count)
@@ -460,16 +439,15 @@ int_cache_remove(Py_ssize_t key_count)
     }
 }
 
-
 //------------------------------------------------------------------------------
 // FrozenAutoMapIterator functions
 
 typedef struct FAMIObject {
-    PyObject_VAR_HEAD
+    PyObject_HEAD
     FAMObject *fam;
     PyArrayObject* keys_array;
     ViewKind kind;
-    int reversed;
+    bool reversed;
     Py_ssize_t index; // current index state, mutated in-place
 } FAMIObject;
 
@@ -478,10 +456,9 @@ static void
 fami_dealloc(FAMIObject *self)
 {
     Py_DECREF(self->fam);
-    Py_TYPE(self)->tp_free((PyObject *)self);
+    PyObject_Del((PyObject *)self);
 }
 
-
 static FAMIObject *
 fami_iter(FAMIObject *self)
 {
@@ -489,7 +466,6 @@ fami_iter(FAMIObject *self)
     return self;
 }
 
-
 // For a FAMI, Return appropriate PyObject for items, keys, and values. When values are needed they are retrieved from the int_cache. For consistency with NumPy array iteration, arrays use PyArray_ToScalar instead of PyArray_GETITEM.
 static PyObject *
 fami_iternext(FAMIObject *self)
@@ -543,32 +519,27 @@ fami_iternext(FAMIObject *self)
     Py_UNREACHABLE();
 }
 
-
 static PyObject *
-fami___length_hint__(FAMIObject *self)
+fami_length_hint(FAMIObject *self)
 {
     Py_ssize_t len = Py_MAX(0, self->fam->keys_size - self->index);
     return PyLong_FromSsize_t(len);
 }
 
-
-static PyObject *fami_new(FAMObject *, ViewKind, int);
-
+static PyObject *fami_new(FAMObject *, ViewKind, bool);
 
 static PyObject *
-fami___reversed__(FAMIObject *self)
+fami_reversed(FAMIObject *self)
 {
     return fami_new(self->fam, self->kind, !self->reversed);
 }
 
-
 static PyMethodDef fami_methods[] = {
-    {"__length_hint__", (PyCFunction)fami___length_hint__, METH_NOARGS, NULL},
-    {"__reversed__", (PyCFunction)fami___reversed__, METH_NOARGS, NULL},
+    {"__length_hint__", (PyCFunction)fami_length_hint, METH_NOARGS, NULL},
+    {"__reversed__", (PyCFunction)fami_reversed, METH_NOARGS, NULL},
     {NULL},
 };
 
-
 static PyTypeObject FAMIType = {
     PyVarObject_HEAD_INIT(NULL, 0)
     .tp_basicsize = sizeof(FAMIObject),
@@ -581,7 +552,7 @@ static PyTypeObject FAMIType = {
 
 
 static PyObject *
-fami_new(FAMObject *fam, ViewKind kind, int reversed)
+fami_new(FAMObject *fam, ViewKind kind, bool reversed)
 {
     FAMIObject *fami = PyObject_New(FAMIObject, &FAMIType);
     if (!fami) {
@@ -606,7 +577,7 @@ fami_new(FAMObject *fam, ViewKind kind, int reversed)
 
 // A FAMVObject contains a reference to the FAM from which it was derived
 typedef struct FAMVObject{
-    PyObject_VAR_HEAD
+    PyObject_HEAD
     FAMObject *fam;
     ViewKind kind;
 } FAMVObject;
@@ -676,28 +647,28 @@ static void
 famv_dealloc(FAMVObject *self)
 {
     Py_DECREF(self->fam);
-    Py_TYPE(self)->tp_free((PyObject *)self);
+    PyObject_Del((PyObject *)self);
 }
 
 
 static PyObject *
 famv_fami_new(FAMVObject *self)
 {
-    return fami_new(self->fam, self->kind, 0);
+    return fami_new(self->fam, self->kind, false);
 }
 
 
 static PyObject *
-famv___length_hint__(FAMVObject *self)
+famv_length_hint(FAMVObject *self)
 {
     return PyLong_FromSsize_t(self->fam->keys_size);
 }
 
 
 static PyObject *
-famv___reversed__(FAMVObject *self)
+famv_reversed(FAMVObject *self)
 {
-    return fami_new(self->fam, self->kind, 1);
+    return fami_new(self->fam, self->kind, true);
 }
 
 
@@ -734,8 +705,8 @@ famv_richcompare(FAMVObject *self, PyObject *other, int op)
 
 
 static PyMethodDef famv_methods[] = {
-    {"__length_hint__", (PyCFunction) famv___length_hint__, METH_NOARGS, NULL},
-    {"__reversed__", (PyCFunction) famv___reversed__, METH_NOARGS, NULL},
+    {"__length_hint__", (PyCFunction) famv_length_hint, METH_NOARGS, NULL},
+    {"__reversed__", (PyCFunction) famv_reversed, METH_NOARGS, NULL},
     {"isdisjoint", (PyCFunction) famv_isdisjoint, METH_O, NULL},
     {NULL},
 };
@@ -755,7 +726,7 @@ static PyTypeObject FAMVType = {
 
 
 static PyObject *
-famv_new(FAMObject *fam, int kind)
+famv_new(FAMObject *fam, ViewKind kind)
 {
     FAMVObject *famv = (FAMVObject *)PyObject_New(FAMVObject, &FAMVType);
     if (!famv) {
@@ -1635,7 +1606,6 @@ grow_table(FAMObject *self, Py_ssize_t keys_size)
             PyErr_SetString(PyExc_NotImplementedError, "Cannot grow table for array keys");
             goto restore;
         }
-
         Py_ssize_t i;
         Py_hash_t h;
         for (table_pos = 0; table_pos < size_old + SCAN - 1; table_pos++) {
@@ -2297,26 +2267,26 @@ fam_hash(FAMObject *self)
 static PyObject *
 fam_iter(FAMObject *self)
 {
-    return fami_new(self, KEYS, 0);
+    return fami_new(self, KEYS, false);
 }
 
 
 static PyObject *
-fam___getnewargs__(FAMObject *self)
+fam_getnewargs(FAMObject *self)
 {
     return PyTuple_Pack(1, self->keys);
 }
 
 
 static PyObject *
-fam___reversed__(FAMObject *self)
+fam_reversed(FAMObject *self)
 {
-    return fami_new(self, KEYS, 1);
+    return fami_new(self, KEYS, true);
 }
 
 
 static PyObject *
-fam___sizeof__(FAMObject *self)
+fam_sizeof(FAMObject *self)
 {
     PyObject *listsizeof = PyObject_CallMethod(self->keys, "__sizeof__", NULL);
     if (!listsizeof) {
@@ -2380,7 +2350,6 @@ fam_new(PyTypeObject *cls, PyObject *args, PyObject *kwargs)
     self->keys = NULL;
     self->key_buffer = NULL;
     self->keys_size = 0;
-
     return (PyObject*)self;
 }
 
@@ -2635,7 +2604,7 @@ fam_richcompare(FAMObject *self, PyObject *other, int op)
 
 
 static PyObject*
-fam___getstate__(FAMObject *self)
+fam_getstate(FAMObject *self)
 {
     PyObject* state = PyTuple_Pack(1, self->keys);
     return state;
@@ -2644,7 +2613,7 @@ fam___getstate__(FAMObject *self)
 
 // State returned here is a tuple of keys, suitable for usage as an `args` argument.
 static PyObject*
-fam___setstate__(FAMObject *self, PyObject *state)
+fam_setstate(FAMObject *self, PyObject *state)
 {
     if (!PyTuple_CheckExact(state) || !PyTuple_GET_SIZE(state)) {
         PyErr_SetString(PyExc_ValueError, "Unexpected pickled object.");
@@ -2661,11 +2630,11 @@ fam___setstate__(FAMObject *self, PyObject *state)
 
 
 static PyMethodDef fam_methods[] = {
-    {"__getnewargs__", (PyCFunction) fam___getnewargs__, METH_NOARGS, NULL},
-    {"__reversed__", (PyCFunction) fam___reversed__, METH_NOARGS, NULL},
-    {"__sizeof__", (PyCFunction) fam___sizeof__, METH_NOARGS, NULL},
-    {"__getstate__", (PyCFunction) fam___getstate__, METH_NOARGS, NULL},
-    {"__setstate__", (PyCFunction) fam___setstate__, METH_O, NULL},
+    {"__getnewargs__", (PyCFunction) fam_getnewargs, METH_NOARGS, NULL},
+    {"__reversed__", (PyCFunction) fam_reversed, METH_NOARGS, NULL},
+    {"__sizeof__", (PyCFunction) fam_sizeof, METH_NOARGS, NULL},
+    {"__getstate__", (PyCFunction) fam_getstate, METH_NOARGS, NULL},
+    {"__setstate__", (PyCFunction) fam_setstate, METH_O, NULL},
     {"get", (PyCFunction) fam_get, METH_VARARGS, NULL},
     {"items", (PyCFunction) fam_items, METH_NOARGS, NULL},
     {"keys", (PyCFunction) fam_keys, METH_NOARGS, NULL},
